Learn R Programming

gbm.auto (version 1.4.0)

calibration: calibration

Description

Internal use only. Jane Elith/John Leathwick 17th March 2005. Calculates calibration statistics for either binomial or count data but the family argument must be specified for the latter a conditional test for the latter will catch most failures to specify the family.

Usage

calibration(obs, preds, family = c("binomial", "bernoulli", "poisson"))

Arguments

obs

Observed data.

preds

Predicted data.

family

Statistical distribution family. Choose one.

Value

roc & calibration stats internally within gbm runs e.g. in gbm.auto.